==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d2/d61/classCocoaSubdriver.js <==
var classCocoaSubdriver =
[
    [ "~CocoaSubdriver", "d2/d61/classCocoaSubdriver.html#a93793785b6e2ca3501357a981edaac74", null ],
    [ "ChangeResolution", "d2/d61/classCocoaSubdriver.html#a36d28dffce6806d819e7b8053a155156", null ],
    [ "Draw", "d2/d61/classCocoaSubdriver.html#a819fac428e927481a073a42734579a45", null ],
    [ "GetHeight", "d2/d61/classCocoaSubdriver.html#a1f22fbed94ef13ee1d658f505582fbf8", null ],
    [ "GetMouseLocation", "d2/d61/classCocoaSubdriver.html#a54aa3b733673b3f69301d5735cad5ea0", null ],
    [ "GetPixelBuffer", "d2/d61/classCocoaSubdriver.html#aafdd5b97278b786cf70b00a9dcee000f", null ],
    [ "GetWidth", "d2/d61/classCocoaSubdriver.html#a086d3e283244df3db1a46f5cb279eab7", null ],
    [ "IsActive", "d2/d61/classCocoaSubdriver.html#a6bbeee5fed93654a496f064e9d8492c9", null ],
    [ "IsFullscreen", "d2/d61/classCocoaSubdriver.html#a58812d22a57cdcc005fa5872104a61c5", null ],
    [ "ListModes", "d2/d61/classCocoaSubdriver.html#a2984be092adfaaf07599c234bf2d4483", null ],
    [ "MakeDirty", "d2/d61/classCocoaSubdriver.html#ae19d6ba1f32137f688f56ba2f6019007", null ],
    [ "MouseIsInsideView", "d2/d61/classCocoaSubdriver.html#a421a53721d68306c5a0f50a42c2b9662", null ],
    [ "PrivateLocalToCG", "d2/d61/classCocoaSubdriver.html#a194fd4123be9f5f3246f23ab95bb47b8", null ],
    [ "SetPortAlphaOpaque", "d2/d61/classCocoaSubdriver.html#aa31fc87e123a4d35f01ffc32cc2922a0", null ],
    [ "ToggleFullscreen", "d2/d61/classCocoaSubdriver.html#ab985782849883999179fbe3687fbd6f1", null ],
    [ "UpdatePalette", "d2/d61/classCocoaSubdriver.html#a17e81307f05c22dc6ddb02be5da6425f", null ],
    [ "WindowResized", "d2/d61/classCocoaSubdriver.html#aa04a4f3f6b4e5aad3a214494fa451db8", null ],
    [ "active", "d2/d61/classCocoaSubdriver.html#ab459ac3a483102de58ec7a2daa367ff6", null ],
    [ "buffer_depth", "d2/d61/classCocoaSubdriver.html#a777f581fc0bbaf0cd104ff9108c9be30", null ],
    [ "cgcontext", "d2/d61/classCocoaSubdriver.html#a08e7b440fb78284359bdf437f9e2c1cc", null ],
    [ "cocoaview", "d2/d61/classCocoaSubdriver.html#a2a6bcdf2ac86ef8fb18742c3b18f5d3b", null ],
    [ "device_depth", "d2/d61/classCocoaSubdriver.html#a4a5c0b756e97f20e000c4db0b020b759", null ],
    [ "device_height", "d2/d61/classCocoaSubdriver.html#a080e191fde9eeecb09a8d53d58b70184", null ],
    [ "device_width", "d2/d61/classCocoaSubdriver.html#a237d7c49e3281c5e9aaf1a71c45a5d73", null ],
    [ "dirty_rects", "d2/d61/classCocoaSubdriver.html#afef12ee62ba19ffd9d99fe9e9c57e275", null ],
    [ "num_dirty_rects", "d2/d61/classCocoaSubdriver.html#a868fc3a700a3bffe534052388dbfddc7", null ],
    [ "palette", "d2/d61/classCocoaSubdriver.html#a9306dd1243960719dd28d0e6c8de2519", null ],
    [ "pixel_buffer", "d2/d61/classCocoaSubdriver.html#a5775462450fff4371f9456aedec4bf53", null ],
    [ "setup", "d2/d61/classCocoaSubdriver.html#acc94bd3fdbd101ebce4467b52f0e620c", null ],
    [ "window", "d2/d61/classCocoaSubdriver.html#a05e3fd7ea0469c362401b6a2b2c38c2d", null ],
    [ "window_buffer", "d2/d61/classCocoaSubdriver.html#a4570c8fee7dea320643d967f2022a87e", null ],
    [ "window_height", "d2/d61/classCocoaSubdriver.html#ad4aedf0221a29d5c30840c990f2ceadd", null ],
    [ "window_pitch", "d2/d61/classCocoaSubdriver.html#a310848c9acbf4bd0b501830ce77d091e", null ],
    [ "window_width", "d2/d61/classCocoaSubdriver.html#a4361a247c790324c4cfb0acdbb34c391", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d2/d61/classCocoaSubdriver.js <==
var classCocoaSubdriver =
[
    [ "~CocoaSubdriver", "d2/d61/classCocoaSubdriver.html#a93793785b6e2ca3501357a981edaac74", null ],
    [ "ChangeResolution", "d2/d61/classCocoaSubdriver.html#a36d28dffce6806d819e7b8053a155156", null ],
    [ "Draw", "d2/d61/classCocoaSubdriver.html#a819fac428e927481a073a42734579a45", null ],
    [ "GetHeight", "d2/d61/classCocoaSubdriver.html#a1f22fbed94ef13ee1d658f505582fbf8", null ],
    [ "GetMouseLocation", "d2/d61/classCocoaSubdriver.html#a54aa3b733673b3f69301d5735cad5ea0", null ],
    [ "GetPixelBuffer", "d2/d61/classCocoaSubdriver.html#aafdd5b97278b786cf70b00a9dcee000f", null ],
    [ "GetWidth", "d2/d61/classCocoaSubdriver.html#a086d3e283244df3db1a46f5cb279eab7", null ],
    [ "IsActive", "d2/d61/classCocoaSubdriver.html#a6bbeee5fed93654a496f064e9d8492c9", null ],
    [ "IsFullscreen", "d2/d61/classCocoaSubdriver.html#a58812d22a57cdcc005fa5872104a61c5", null ],
    [ "ListModes", "d2/d61/classCocoaSubdriver.html#a2984be092adfaaf07599c234bf2d4483", null ],
    [ "MakeDirty", "d2/d61/classCocoaSubdriver.html#ae19d6ba1f32137f688f56ba2f6019007", null ],
    [ "MouseIsInsideView", "d2/d61/classCocoaSubdriver.html#a421a53721d68306c5a0f50a42c2b9662", null ],
    [ "PrivateLocalToCG", "d2/d61/classCocoaSubdriver.html#a194fd4123be9f5f3246f23ab95bb47b8", null ],
    [ "ToggleFullscreen", "d2/d61/classCocoaSubdriver.html#a3bb6dd3a6ac060d6a51e54a8c874c79a", null ],
    [ "UpdatePalette", "d2/d61/classCocoaSubdriver.html#a17e81307f05c22dc6ddb02be5da6425f", null ],
    [ "WindowResized", "d2/d61/classCocoaSubdriver.html#aa04a4f3f6b4e5aad3a214494fa451db8", null ],
    [ "active", "d2/d61/classCocoaSubdriver.html#ab459ac3a483102de58ec7a2daa367ff6", null ],
    [ "buffer_depth", "d2/d61/classCocoaSubdriver.html#a777f581fc0bbaf0cd104ff9108c9be30", null ],
    [ "cgcontext", "d2/d61/classCocoaSubdriver.html#a08e7b440fb78284359bdf437f9e2c1cc", null ],
    [ "cocoaview", "d2/d61/classCocoaSubdriver.html#a2a6bcdf2ac86ef8fb18742c3b18f5d3b", null ],
    [ "color_space", "d2/d61/classCocoaSubdriver.html#aa2280ec43597281d39fba2b678324114", null ],
    [ "device_depth", "d2/d61/classCocoaSubdriver.html#a4a5c0b756e97f20e000c4db0b020b759", null ],
    [ "device_height", "d2/d61/classCocoaSubdriver.html#a080e191fde9eeecb09a8d53d58b70184", null ],
    [ "device_width", "d2/d61/classCocoaSubdriver.html#a237d7c49e3281c5e9aaf1a71c45a5d73", null ],
    [ "dirty_rects", "d2/d61/classCocoaSubdriver.html#afef12ee62ba19ffd9d99fe9e9c57e275", null ],
    [ "num_dirty_rects", "d2/d61/classCocoaSubdriver.html#a868fc3a700a3bffe534052388dbfddc7", null ],
    [ "palette", "d2/d61/classCocoaSubdriver.html#a9306dd1243960719dd28d0e6c8de2519", null ],
    [ "pixel_buffer", "d2/d61/classCocoaSubdriver.html#a5775462450fff4371f9456aedec4bf53", null ],
    [ "setup", "d2/d61/classCocoaSubdriver.html#acc94bd3fdbd101ebce4467b52f0e620c", null ],
    [ "window", "d2/d61/classCocoaSubdriver.html#a05e3fd7ea0469c362401b6a2b2c38c2d", null ],
    [ "window_buffer", "d2/d61/classCocoaSubdriver.html#a4570c8fee7dea320643d967f2022a87e", null ],
    [ "window_height", "d2/d61/classCocoaSubdriver.html#ad4aedf0221a29d5c30840c990f2ceadd", null ],
    [ "window_pitch", "d2/d61/classCocoaSubdriver.html#a310848c9acbf4bd0b501830ce77d091e", null ],
    [ "window_width", "d2/d61/classCocoaSubdriver.html#a4361a247c790324c4cfb0acdbb34c391", null ]
];
